@@ -7,7 +7,11 @@
  * directory or online at http://www.openafs.org/dl/license10.html
  */
 
+#include <afsconfig.h>
 #include <afs/param.h>
+
+RCSID("$Header: /cvs/openafs/src/auth/cellconfig.c,v 1.13 2001/07/16 00:20:38 shadow Exp $");
+
 #include <afs/stds.h>
 #include <afs/pthread_glock.h>
 #ifdef UKERNEL
@@ -26,7 +30,11 @@
 #include <netdb.h>
 #include <sys/file.h>
 #include <sys/time.h>
-#endif
+#ifdef AFS_AFSDB_ENV
+#include <arpa/nameser.h>
+#include <resolv.h>
+#endif /* AFS_AFSDB_ENV */
+#endif /* AFS_NT40_ENV */
 #include <errno.h>
 #include <ctype.h>
 #include <time.h>
@@ -38,10 +46,6 @@
 #include "cellconfig.h"
 #include "keys.h"
 
-#ifdef AFS_DNS
-#include "DNS_AFS.h"
-#endif /* AFS_DNS */
-
 static ParseHostLine();
 static ParseCellLine();
 static afsconf_OpenInternal();
@@ -546,6 +550,100 @@ afsconf_GetExtendedCellInfo(adir, acellName, aservice, acellInfo, clones)
     return code;
 }
 
+#ifdef AFS_AFSDB_ENV
+afsconf_GetAfsdbInfo(acellName, aservice, acellInfo)
+    char *acellName;
+    char *aservice;
+    struct afsconf_cell *acellInfo;
+{
+    afs_int32 code;
+    int tservice, len, i;
+    unsigned char answer[1024];
+    unsigned char *p;
+    char host[256];
+    int server_num = 0;
+    int minttl = 0;
+
+    /* The resolver isn't always MT-safe.. Perhaps this ought to be
+     * replaced with a more fine-grained lock just for the resolver
+     * operations.
+     */
+    LOCK_GLOBAL_MUTEX
+    len = res_search(acellName, C_IN, T_AFSDB, answer, sizeof(answer));
+    UNLOCK_GLOBAL_MUTEX
+
+    if (len < 0)
+	return AFSCONF_NOTFOUND;
+
+    p = answer + sizeof(HEADER);	/* Skip header */
+    code = dn_expand(answer, answer + len, p, host, sizeof(host));
+    if (code < 0)
+	return AFSCONF_NOTFOUND;
+    strncpy(acellInfo->name, host, sizeof(acellInfo->name));
+
+    p += code + QFIXEDSZ;	/* Skip name */
+
+    while (p < answer + len) {
+	int type, ttl, size;
+
+	code = dn_expand(answer, answer + len, p, host, sizeof(host));
+	if (code < 0)
+	    return AFSCONF_NOTFOUND;
+
+	p += code;	/* Skip the name */
+	type = (p[0] << 8) | p[1];
+	p += 4;		/* Skip type and class */
+	ttl = (p[0] << 24) | (p[1] << 16) | (p[2] << 8) | p[3];
+	p += 4;		/* Skip the TTL */
+	size = (p[0] << 8) | p[1];
+	p += 2;		/* Skip the size */
+
+	if (type == T_AFSDB) {
+	    struct hostent *he;
+	    short afsdb_type;
+
+	    afsdb_type = (p[0] << 8) | p[1];
+	    code = dn_expand(answer, answer+len, p+2, host, sizeof(host));
+	    if (code < 0)
+		return AFSCONF_NOTFOUND;
+
+	    if ((afsdb_type == 1) &&
+		(server_num < MAXHOSTSPERCELL) &&
+		/* Do we want to get TTL data for the A record as well? */
+		(he = gethostbyname(host))) {
+		afs_int32 ipaddr;
+		memcpy(&ipaddr, he->h_addr, he->h_length);
+		acellInfo->hostAddr[server_num].sin_addr.s_addr = ipaddr;
+		strncpy(acellInfo->hostName[server_num], host,
+			sizeof(acellInfo->hostName[server_num]));
+		server_num++;
+
+		if (!minttl || ttl < minttl) minttl = ttl;
+	    }
+	}
+
+	p += size;
+    }
+
+    if (server_num == 0)		/* No AFSDB records */
+	return AFSCONF_NOTFOUND;
+    acellInfo->numServers = server_num;
+
+    if (aservice) {
+	tservice = afsconf_FindService(aservice);
+	if (tservice < 0)
+	    return AFSCONF_NOTFOUND;  /* service not found */
+	for (i=0; i<acellInfo->numServers; i++) {
+	    acellInfo->hostAddr[i].sin_port = tservice;
+	}
+    }
+
+    acellInfo->timeout = minttl ? (time(0) + minttl) : 0;
+
+    return 0;
+}
+#endif /* AFS_AFSDB_ENV */
+
 afsconf_GetCellInfo(adir, acellName, aservice, acellInfo)
 struct afsconf_dir *adir;
 char *aservice;
@@ -559,53 +657,6 @@ struct afsconf_cell *acellInfo; {
     int cnLen, ambig;
     char tbuffer[64];
 
-#ifdef AFS_DNS
-    /////////////////////////////////////////////
-    //TRY A DNS QUERY FOR THAT CELL FIRST!
-
-    struct afsconf_entry DNSce;
-    char *DNStmpStrp; /* a temp string pointer */
-    struct hostent *thp;
-
-
-    DNSce.cellInfo.numServers=0;
-    DNSce.next = NULL;
-    DNStmpStrp = getAFSServer(acellName);
-    while(DNStmpStrp != NULL) {
-      strcpy(DNSce.cellInfo.hostName[DNSce.cellInfo.numServers],DNStmpStrp);
-      thp = gethostbyname(DNStmpStrp);
-      if (!thp)
-     thp = DNSgetHostByName(DNStmpStrp);
-      if (thp) {
-     memcpy(&DNSce.cellInfo.hostAddr[DNSce.cellInfo.numServers].sin_addr.s_addr, thp->h_addr,
-            sizeof(long));
-     DNSce.cellInfo.hostAddr[DNSce.cellInfo.numServers].sin_family = AF_INET;
-     /* sin_port supplied by connection code */
-      }
-      DNSce.cellInfo.numServers++; /* add the server to the VLDB server list */
-      DNStmpStrp = getAFSServer(acellName);
-    };
-
-    if (DNSce.cellInfo.numServers>0) {
-      strcpy(&(DNSce.cellInfo.name),acellName);
-      *acellInfo = DNSce.cellInfo; /* structure assignment */
-      if (aservice) {
-     LOCK_GLOBAL_MUTEX
-     tservice = afsconf_FindService(aservice);
-     UNLOCK_GLOBAL_MUTEX
-     if (tservice < 0) {
-       return AFSCONF_NOTFOUND;  /* service not found */
-     }
-     for(i=0;i<acellInfo->numServers;i++) {
-       acellInfo->hostAddr[i].sin_port = tservice;
-     }
-      };
-      return 0;
-    };
-    /////////////////////////////////////////////
-#endif /* AFS_DNS */
-
-
     LOCK_GLOBAL_MUTEX
     if (adir) afsconf_Check(adir);
     if (acellName) {
@@ -654,12 +705,17 @@ struct afsconf_cell *acellInfo; {
 		acellInfo->hostAddr[i].sin_port = tservice;
 	    }
 	}
+	acellInfo->timeout = 0;
 	UNLOCK_GLOBAL_MUTEX
 	return 0;
     }
     else {
 	UNLOCK_GLOBAL_MUTEX
+#ifdef AFS_AFSDB_ENV
+	return afsconf_GetAfsdbInfo(acellName, aservice, acellInfo);
+#else
 	return AFSCONF_NOTFOUND;
+#endif /* AFS_AFSDB_ENV */
     }
 }
 
@@ -796,8 +852,12 @@ afsconf_GetKeys(adir, astr)
 struct afsconf_dir *adir;
 struct afsconf_keys *astr;
 {
+    register afs_int32 code;
+
     LOCK_GLOBAL_MUTEX
-    afsconf_Check(adir);
+    code = afsconf_Check(adir);
+    if (code)
+	return AFSCONF_FAILURE;
     bcopy(adir->keystr, astr, sizeof(struct afsconf_keys));
     UNLOCK_GLOBAL_MUTEX
     return 0;
@@ -814,9 +874,12 @@ afs_int32 afsconf_GetLatestKey(adir, avno, akey)
     register struct afsconf_key *tk;
     register afs_int32 best;
     struct afsconf_key *bestk;
+    register afs_int32 code;
     
     LOCK_GLOBAL_MUTEX
-    afsconf_Check(adir);
+    code = afsconf_Check(adir);
+    if (code)
+	return AFSCONF_FAILURE;
     maxa = adir->keystr->nkeys;
 
     best = -1;	    /* highest kvno we've seen yet */
@@ -846,9 +909,12 @@ char *akey;
 {
     register int i, maxa;
     register struct afsconf_key *tk;
+    register afs_int32 code;
 
     LOCK_GLOBAL_MUTEX
-    afsconf_Check(adir);
+    code = afsconf_Check(adir);
+    if (code)
+	return AFSCONF_FAILURE;
     maxa = adir->keystr->nkeys;
 
     for(tk = adir->keystr->key,i=0;i<maxa;i++,tk++) {
