@@ -7,9 +7,11 @@
  * directory or online at http://www.openafs.org/dl/license10.html
  */
 
-#ifndef lint
-#endif
+#include <afsconfig.h>
 #include <afs/param.h>
+
+RCSID("$Header: /cvs/openafs/src/ptserver/pts.c,v 1.6 2001/07/12 19:58:54 shadow Exp $");
+
 #include <stdio.h>
 #include <string.h>
 #ifdef	AFS_AIX32_ENV
@@ -125,8 +127,11 @@ CreateGroup (as)
 	if (code) {
 	    if (owner || id) 
 		com_err (whoami, code,
-			 "; unable to create group %s with id %d owned by '%s' %s",
-			 namei->data, id, owner, (force?"(ignored)":""));
+			 "; unable to create group %s with id %d%s%s%s%s",
+			 namei->data, id, owner ? " owned by '" : "",
+			 owner ? owner : "",
+			 owner ? "'" : "",
+			 (force ? " (ignored)" : ""));
 	    else com_err (whoami, code,
 			 "; unable to create group %s %s", namei->data, (force?"(ignored)":""));
 	    if (!force)
