@@ -1,4 +1,4 @@
-/*
+ /*
  * Copyright 2000, International Business Machines Corporation and others.
  * All Rights Reserved.
  * 
@@ -7,9 +7,20 @@
  * directory or online at http://www.openafs.org/dl/license10.html
  */
 
-#ifdef	KERNEL
+#include <afsconfig.h>
+#ifdef KERNEL
 #include "../afs/param.h"
+#else
+#include <afs/param.h>
+#endif
+
+RCSID("$Header: /cvs/openafs/src/rx/rx_rdwr.c,v 1.10 2001/07/12 19:58:56 shadow Exp $");
+
+#ifdef KERNEL
 #ifndef UKERNEL
+#if defined(AFS_DARWIN_ENV) || defined(AFS_FBSD_ENV)
+#include "../afs/sysincludes.h"
+#else
 #include "../h/types.h"
 #include "../h/time.h"
 #include "../h/stat.h"
@@ -23,6 +34,7 @@
 #if defined(AFS_SGI_ENV)
 #include "../afs/sysincludes.h"
 #endif
+#endif
 #include "../afs/afs_args.h"
 #include "../afs/afs_osi.h"
 #if	(defined(AFS_AUX_ENV) || defined(AFS_AIX_ENV))
@@ -34,7 +46,6 @@
 #ifdef RXDEBUG
 #undef RXDEBUG	    /* turn off debugging */
 #endif /* RXDEBUG */
-#include "../afsint/afsint.h"
 
 #include "../rx/rx_kmutex.h"
 #include "../rx/rx_kernel.h"
@@ -52,7 +63,6 @@
 #undef register
 #endif  /* AFS_ALPHA_ENV */
 #else /* KERNEL */
-# include <afs/param.h>
 # include <sys/types.h>
 #ifndef AFS_NT40_ENV
 # include <sys/socket.h>
@@ -62,6 +72,16 @@
 # include <sys/stat.h>
 # include <sys/time.h>
 #endif
+#ifdef HAVE_STRINGS_H
+#include <strings.h>
+#else
+#ifdef HAVE_STRING_H
+#include <string.h>
+#endif
+#endif
+#ifdef HAVE_UNISTD_H
+#include <unistd.h>
+#endif
 # include "rx_user.h"
 # include "rx_clock.h"
 # include "rx_queue.h"
@@ -70,7 +90,6 @@
 # include "rx_internal.h"
 #endif /* KERNEL */
 
-
 #ifdef RX_LOCKS_DB
 /* rxdb_fileID is used to identify the lock location, along with line#. */
 static int rxdb_fileID = RXDB_FILE_RX_RDWR;
@@ -125,7 +144,7 @@ int rxi_ReadProc(call, buf, nbytes)
                * work.  It may reduce the length of the packet by up
                * to conn->maxTrailerSize, to reflect the length of the
                * data + the header. */
-	      if (error = RXS_CheckPacket(conn->securityObject, call, rp)) {
+	      if ((error = RXS_CheckPacket(conn->securityObject, call, rp))) {
 		/* Used to merely shut down the call, but now we 
 		 * shut down the whole connection since this may 
 		 * indicate an attempt to hijack it */
@@ -398,7 +417,7 @@ int rxi_FillReadVec(call, seq, serial, flags)
     struct rx_packet *rp;
     struct rx_packet *curp;
     struct iovec *call_iov;
-    struct iovec *cur_iov;
+    struct iovec *cur_iov = NULL;
 
     curp = call->currentPacket;
     if (curp) {
@@ -421,7 +440,7 @@ int rxi_FillReadVec(call, seq, serial, flags)
              * work.  It may reduce the length of the packet by up
              * to conn->maxTrailerSize, to reflect the length of the
              * data + the header. */
-	    if (error = RXS_CheckPacket(conn->securityObject, call, rp)) {
+	    if ((error = RXS_CheckPacket(conn->securityObject, call, rp))) {
 	      /* Used to merely shut down the call, but now we 
 	       * shut down the whole connection since this may 
 	       * indicate an attempt to hijack it */
@@ -729,7 +748,7 @@ int rxi_WriteProc(call, buf, nbytes)
 		}
 #endif /* RX_ENABLE_LOCKS */
 	    }
-	    if (cp = rxi_AllocSendPacket(call, nbytes)) {
+	    if ((cp = rxi_AllocSendPacket(call, nbytes))) {
 		call->currentPacket = cp;
 		call->nFree = cp->length;
 		call->curvec = 1;   /* 0th vec is always header */
@@ -1103,7 +1122,6 @@ int rxi_WritevProc(call, iov, nio, nbytes)
     int nio;
     int nbytes;
 {
-    struct rx_connection *conn = call->conn;
     struct rx_packet *cp = call->currentPacket;
     register struct rx_packet *tp; /* Temporary packet pointer */
     register struct rx_packet *nxp; /* Next packet pointer, for queue_Scan */
@@ -1151,8 +1169,6 @@ int rxi_WritevProc(call, iov, nio, nbytes)
     nextio = 0;
     queue_Init(&tmpq);
     do {
-	unsigned int t;
-
 	if (call->nFree == 0 && cp) {
 	    clock_NewTime(); /* Bogus:  need new time package */
 	    /* The 0, below, specifies that it is not the last packet: 
