@@ -16,7 +16,11 @@
 /*                                                                        */
 /* ********************************************************************** */
 
+#include <afsconfig.h>
 #include <afs/param.h>
+
+RCSID("$Header: /cvs/openafs/src/util/serverLog.c,v 1.15 2001/07/12 19:59:23 shadow Exp $");
+
 #include <stdio.h>
 #ifdef AFS_NT40_ENV
 #include <io.h>
@@ -27,14 +31,17 @@
 #endif
 #include <sys/param.h>
 #include <sys/time.h>
+#include <syslog.h>
 #endif
 #include <afs/procmgmt.h>  /* signal(), kill(), wait(), etc. */
 #include <fcntl.h>
 #include <afs/stds.h>
-#if defined(AFS_SUN5_ENV) || defined(AFS_NT40_ENV)
-#include <string.h>
-#else
+#ifdef HAVE_STRINGS_H
 #include <strings.h>
+#else
+#ifdef HAVE_STRING_H
+#include <string.h>
+#endif
 #endif
 #include "afsutil.h"
 #include "fileutil.h"
@@ -60,10 +67,15 @@ static pthread_mutex_t serverLogMutex;
 #define F_OK 0
 #endif
 
-char *threadname();
+char *(*threadNameProgram)();
 
 static int serverLogFD = -1;
 
+#ifndef AFS_NT40_ENV
+int serverLogSyslog = 0;
+int serverLogSyslogFacility = LOG_DAEMON;
+#endif
+
 #include <stdarg.h>
 int LogLevel;
 int mrafsStyleLogs = 0;
@@ -76,7 +88,7 @@ void WriteLogBuffer(buf,len)
 {
     LOCK_SERVERLOG();
     if (serverLogFD > 0)
-        write(serverLogFD, buf, len);
+      write(serverLogFD, buf, len);
     UNLOCK_SERVERLOG();
 }
 
@@ -90,7 +102,6 @@ void FSLog (const char *format, ...)
     char tbuffer[1024];
     char *info;
     int len;
-    int i;
     char *name;
 
     currenttime = time(0);
@@ -99,7 +110,7 @@ void FSLog (const char *format, ...)
     info = &timeStamp[25];
 
     if (mrafsStyleLogs) {
-       name = threadname();
+       name = (*threadNameProgram)();
        sprintf(info, "[%s] ", name);
        info += strlen(info);
     }
@@ -110,23 +121,31 @@ void FSLog (const char *format, ...)
 
     len = strlen(tbuffer);
     LOCK_SERVERLOG();
-    if (serverLogFD > 0)
-	write(serverLogFD, tbuffer, len);
+#ifndef AFS_NT40_ENV
+    if ( serverLogSyslog ){
+	syslog(LOG_INFO, "%s", info);
+    } else 
+#endif
+	if (serverLogFD > 0)
+	    write(serverLogFD, tbuffer, len);
     UNLOCK_SERVERLOG();
 
-#if !defined(AFS_PTHREAD_ENV)
-    fflush(stdout);
-    fflush(stderr);     /* in case they're sharing the same FD */
+#if !defined(AFS_PTHREAD_ENV) && !defined(AFS_NT40_ENV)
+    if ( ! serverLogSyslog ) {
+        fflush(stdout);
+        fflush(stderr);     /* in case they're sharing the same FD */
+    }
 #endif
 }
 
-static void DebugOn(int loglevel)
+static int DebugOn(int loglevel)
 {
     if (loglevel == 0) {
         ViceLog(0, ("Reset Debug levels to 0\n"));
     } else {
         ViceLog(0, ("Set Debug On level = %d\n",loglevel));
     }
+    return 0;
 } /*DebugOn*/
 
 
@@ -160,7 +179,7 @@ void ResetDebug_Signal(int signo)
 #if defined(AFS_PTHREAD_ENV)
     DebugOn(LogLevel);
 #else /* AFS_PTHREAD_ENV */
-    IOMGR_SoftSig(DebugOn, LogLevel);
+    IOMGR_SoftSig(DebugOn, (void *)LogLevel);
 #endif /* AFS_PTHREAD_ENV */
 
     signal(signo, ResetDebug_Signal);   /* on some platforms, this signal */
@@ -189,6 +208,13 @@ int OpenLog(const char *fileName)
     struct tm *TimeFields;
     char FileName[MAXPATHLEN]; 
 
+#ifndef AFS_NT40_ENV
+    if ( serverLogSyslog ) {
+	openlog(NULL, LOG_PID, serverLogSyslogFacility);
+	return(0);
+    }
+#endif
+
     if (mrafsStyleLogs) {
         TM_GetTimeOfDay(&Start, 0);
         TimeFields = localtime(&Start.tv_sec);
@@ -244,6 +270,12 @@ int ReOpenLog(const char *fileName)
     if (access(fileName, F_OK)==0)
 	return 0; /* exists, no need to reopen. */
 
+#if !defined(AFS_NT40_ENV)
+    if ( serverLogSyslog ) {
+	return 0;
+    }
+#endif
+
 #if defined(AFS_PTHREAD_ENV)
     LOCK_SERVERLOG();
     if (serverLogFD > 0)
